aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/opengl
diff options
context:
space:
mode:
Diffstat (limited to 'src/jogl/classes/com/jogamp/opengl')
-rw-r--r--src/jogl/classes/com/jogamp/opengl/util/av/GLMediaPlayer.java10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/jogl/classes/com/jogamp/opengl/util/av/GLMediaPlayer.java b/src/jogl/classes/com/jogamp/opengl/util/av/GLMediaPlayer.java
index 698504205..91211df58 100644
--- a/src/jogl/classes/com/jogamp/opengl/util/av/GLMediaPlayer.java
+++ b/src/jogl/classes/com/jogamp/opengl/util/av/GLMediaPlayer.java
@@ -781,18 +781,24 @@ public interface GLMediaPlayer extends TextureSequence {
/**
* <i>Warning:</i> Optional information, may not be supported by implementation.
* @return the code of the video stream, if available
*/
public String getVideoCodec();
/**
* <i>Warning:</i> Optional information, may not be supported by implementation.
* @return the code of the audio stream, if available
*/
public String getAudioCodec();
/**
* <i>Warning:</i> Optional information, may not be supported by implementation.
+ * @return the codec of the subtitle stream, if available
+ */
+ public String getSubtitleCodec();
+
+ /**
+ * <i>Warning:</i> Optional information, may not be supported by implementation.
* @return the total number of video frames
*/
public int getVideoFrames();
@@ -781,18 +781,24 @@ public interface GLMediaPlayer extends TextureSequence {
/**
* <i>Warning:</i> Optional information, may not be supported by implementation.
- * @return the code of the video stream, if available
+ * @return the codec of the video stream, if available
*/
public String getVideoCodec();
@@ -781,18 +781,24 @@ public interface GLMediaPlayer extends TextureSequence {
/**
* <i>Warning:</i> Optional information, may not be supported by implementation.
- * @return the code of the audio stream, if available
+ * @return the codec of the audio stream, if available
*/
public String getAudioCodec();